<?php

/** @noinspection PhpUnusedLocalVariableInspection */
/** @noinspection PhpInconsistentReturnPointsInspection */

namespace Drupal\skilling\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\skilling\MakeStarterContent\MakeNodes;
use Drupal\skilling\MakeStarterContent\MakeStarterContent;
use Drupal\skilling\MakeStarterContent\MakeUsers;
use Drupal\skilling\SkillingConstants;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\skilling\Utilities as SkillingUtilities;
use Symfony\Component\HttpFoundation\Session\Session;

/**
 * Controller for skilling administration pages.
 */
class AdminController extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The skilling utilities service.
   *
   * @var \Drupal\skilling\Utilities
   */
  protected $skillingUtilities;

  /**
   * The session service.
   *
   * @var \Symfony\Component\HttpFoundation\Session\Session
   */
  protected $sessionService;

  /**
   * Service that makes starter content.
   *
   * @var \Drupal\skilling\MakeStarterContent\MakeStarterContent
   */
  protected $makeStarterContentService;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new AdminController object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity type manager service.
   * @param \Drupal\skilling\Utilities $skilling_utilities
   *   Skilling utilities service.
   * @param \Drupal\skilling\MakeStarterContent\MakeNodes $makeNodes
   *   Service to make nodes.
   * @param \Drupal\skilling\MakeStarterContent\MakeUsers $makeUsers
   *   Service to make users.
   * @param \Symfony\Component\HttpFoundation\Session\Session $session
   *   Symfony session service.
   * @param \Drupal\skilling\MakeStarterContent\MakeStarterContent $makeStarterContentService
   *   Service that makes starter content.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, SkillingUtilities $skilling_utilities, MakeNodes $makeNodes, MakeUsers $makeUsers, Session $session, MakeStarterContent $makeStarterContentService, MessengerInterface $messenger) {
    $this->entityTypeManager = $entity_type_manager;
    $this->skillingUtilities = $skilling_utilities;
    $this->makeNodesService = $makeNodes;
    $this->makeUsersService = $makeUsers;
    $this->sessionService = $session;
    $this->makeStarterContentService = $makeStarterContentService;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /* @noinspection PhpParamsInspection */
    return new static(
      $container->get('entity_type.manager'),
      $container->get('skilling.utilities'),
      $container->get('skilling.starter.make_nodes'),
      $container->get('skilling.starter.make_users'),
      $container->get('session'),
      $container->get('skilling.starter.make_starter_content'),
      $container->get('messenger')
    );
  }

  /**
   * Launch delete history.
   *
   * @return array
   *   Return Hello string.
   */
  public function launchDeleteHistory() {
    $build['explanation'] = [
      '#type' => 'markup',
      '#markup' => '<p>' . $this->t(
        'You can delete all of the student history records.'
      ) . '</p>',
    ];
    return $build;
  }

  /**
   * Delete history.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Where to go.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Exception
   */
  public function deleteHistory() {
    $storageHandler = $this->entityTypeManager->getStorage('node');
    $nids = $storageHandler->getQuery()
      ->condition('type', SkillingConstants::HISTORY_CONTENT_TYPE)
      ->execute();
    $count = count($nids);
    $nodes = $storageHandler->loadMultiple($nids);
    $storageHandler->delete($nodes);
    $this->messenger->addStatus(
      $this->t('History deleted: @n events.', ['@n' => $count])
    );
    return $this->redirect('skilling.admin.config.delete_history');
  }

}
